==> haskell-text-printer-0.5-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-printer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-printer
version: 0.5
id: text-printer-0.5-841jXq5bFX06bZ6MMnsbyd
key: text-printer-0.5-841jXq5bFX06bZ6MMnsbyd
license: BSD3
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/text-printer
synopsis: Abstract interface for text builders/printers.
description:
    This package provides an interface for injecting text into monoids such as
    builders and printers.
category: Text
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
exposed-modules:
    Text.Printer Text.Printer.Integral Text.Printer.Fractional
abi: 649275844abdfa94913102dd7b44c932
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/text-printer-0.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/text-printer-0.5
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/text-printer-0.5
hs-libraries: HStext-printer-0.5-841jXq5bFX06bZ6MMnsbyd
depends:
    base-4.9.0.0 bytestring-0.10.8.1 pretty-1.1.3.3
    semigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
    text-latin1-0.3-JEcsemhHVZw6TQLW0QZTnO
haddock-interfaces: /usr/share/doc/haskell-text-printer/html/text-printer.haddock
haddock-html: /usr/share/doc/haskell-text-printer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-printer-0.5-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-printer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-printer
version: 0.5
id: text-printer-0.5-LEBVCr4dyYi1RN0kjLDrdn
key: text-printer-0.5-LEBVCr4dyYi1RN0kjLDrdn
license: BSD3
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/text-printer
synopsis: Abstract interface for text builders/printers.
description:
    This package provides an interface for injecting text into monoids such as
    builders and printers.
category: Text
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
exposed-modules:
    Text.Printer Text.Printer.Integral Text.Printer.Fractional
abi: 0547694595de167a2a61cf3f67b55e64
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/text-printer-0.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/text-printer-0.5
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/text-printer-0.5
hs-libraries: HStext-printer-0.5-LEBVCr4dyYi1RN0kjLDrdn
depends:
    base-4.9.0.0 bytestring-0.10.8.1 pretty-1.1.3.3
    semigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
    text-latin1-0.3-9VPHsWoLgvzJ6rNXX3I0m4
haddock-interfaces: /usr/share/doc/haskell-text-printer/html/text-printer.haddock
haddock-html: /usr/share/doc/haskell-text-printer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
